import request from '@/utils/request'

// 查询停车场,开通停车场的小区同步过来列表
export function listParking(data) {
  return request({
    url: '/tParking/list',
    method: 'post',
    data: data
  })
}
// 查询停车场名称列表-车辆列表页面下拉框
export function listParkName() {
  return request({
    url: '/tParking/getParkNameList',
    method: 'post',
  })
}

// 查询停车场,开通停车场的小区同步过来详细
export function getParking(id) {
  return request({
    url: '/tParking/' + id,
    method: 'get'
  })
}

// 新增停车场,开通停车场的小区同步过来
export function addParking(data) {
  return request({
    url: '/tParking',
    method: 'post',
    data: data
  })
}

// 修改停车场,开通停车场的小区同步过来
export function updateParking(data) {
  return request({
    url: '/tParking',
    method: 'put',
    data: data
  })
}

// 删除停车场,开通停车场的小区同步过来
export function delParking(id) {
  return request({
    url: '/tParking/' + id,
    method: 'delete'
  })
}
// 导入停车场
export function importData(data) {
  return request({
    url: '/tParking/import',
    method: 'post',
    data: data
  })
}

// 导出停车场,开通停车场的小区同步过来
export function exportParking(data) {
  return request({
    url: '/tParking/export',
    method: 'post',
    data: data
  })
}
